This function fits the Gompertz Curve in Time Series Data along with estimates of the parameters and predicted value.
Usage
gmptz(y)
Arguments
y
a numeric vector
Value
a.hat , b.hat , k.hat : the estimated values of the parameters a,b and k.
predicted.value : the predicted values of y
Details
The Gompertz curve is a type of mathematical model for a Time Series. It is a sigmoid function which describes growth as being slowest at the start and end of a given time period. The equation of Gompertz curve is given by , Y=k*a^(b^x)
Taking Logarithm on both sides we get, LogY=Logk+(b^x)*Loga ; OR, Z=A+B(C^x) , where Z=LogY , A=logk , B=loga ,C=b; It is a form of Modified Exponential.So ,now we can apply Method Of Group Average.